/***************************************************************************
 *   Copyright (C) 2005 by Christian Muehlhaeuser, Last.fm Ltd.            *
 *   chris@last.fm                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA  02111-1307, USA.          *
 ***************************************************************************/

#include <QApplication>

#include "player.h"
#include "settings.h"
#include "localconnector.h"


bool
transmitCli( QString parameter )
{
    QTcpSocket *socket = new QTcpSocket( 0 );
    socket->connectToHost( QHostAddress::LocalHost, 32213 );
    if ( socket->waitForConnected( 500 ) )
    {
        if ( parameter.length() > 0 )
        {
            socket->write( parameter.toLocal8Bit(), parameter.length() );
            socket->flush();
        }

        socket->close();
        delete socket;
        return true;
    }

    delete socket;
    return false;
}


int main( int argc, char *argv[] )
{
    QApplication app( argc, argv );

    #ifdef Q_WS_X11
    QApplication::setStyle( "plastique" );
    #endif

    Settings *settings = new Settings();
    QString cli;

    for ( int i = 1; i < argc; i ++ )
    {
        if ( QString( argv[i] ).contains( "--debug" ) )
            settings->setDebug( true );

        if ( QString( argv[i] ).contains( "lastfm://" ) )
            cli = argv[i];
    }

    // check for another instance running
    #ifndef Q_WS_MAC
    if ( !cli.isEmpty() && cli.length() > 9 )
        cli = cli.remove( 0, 9 );
    #endif

    if ( transmitCli( cli ) )
        qDebug() << "Data passed to running instance, shutting down";
    else
    {
        LocalConnector *localConnector = new LocalConnector();

        Player *window = new Player( 0, cli );
        window->setWindowTitle( "Last.fm Player" );
        window->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
        window->show();

        return app.exec();
        delete localConnector;
    }

    delete settings;
    return 0;
}
